@@ -1,7 +1,8 @@
 from abc import ABC, abstractmethod
 from typing import List
 
-from reinvent_scoring.chemistry.general import GeneralChemistry
+from reinvent_chemistry.conversions import Conversions
+
 from reinvent_scoring.scoring.component_parameters import ComponentParameters
 from reinvent_scoring.scoring.score_summary import ComponentSummary
 from reinvent_scoring.scoring.enums import ComponentSpecificParametersEnum
@@ -12,7 +13,7 @@ class BaseScoreComponent(ABC):
     def __init__(self, parameters: ComponentParameters):
         self.component_specific_parameters = ComponentSpecificParametersEnum()
         self.parameters = parameters
-        self._chemistry = GeneralChemistry()
+        self._chemistry = Conversions()
 
     @abstractmethod
     def calculate_score(self, molecules: List, step=-1) -> ComponentSummary:
